@@ -20,11 +20,11 @@
 #' @param labels vector of labels for plots (titles and axis labels)
 #' @param col1 first color to use in plot (for expected values)
 #' @param col2 second color to use in plot (for observations and intervals)
-#' @param pwidth width of plot written to PNG file
-#' @param pheight height of plot written to PNG file
+#' @param pwidth width of plot
+#' @param pheight height of plot
 #' @param punits units for PNG file
 #' @param res resolution for PNG file
-#' @param ptsize ptsize for PNG file
+#' @param ptsize point size for PNG file
 #' @param cex.main character expansion for plot titles
 #' @param verbose report progress to R GUI?
 #' @author Ian Taylor, Ian Stewart
@@ -45,7 +45,7 @@ SSplotMnwt <-
            "Mean weight in", #6
            "for"),     #7
            col1="blue", col2="black",
-           pwidth=7,pheight=7,punits="in",res=300,ptsize=12,
+           pwidth=6.5,pheight=5.0,punits="in",res=300,ptsize=10,
            cex.main=1,
            plotdir="default", verbose=TRUE)
 {
