@@ -1,10 +1,10 @@
 #' make table comparing quantities across models
-#' 
+#'
 #' Creates a table comparing key quantities from multiple models, which is a
 #' reduction of the full information in various parts of the list created using
 #' the \code{SSsummarize} function.
-#' 
-#' 
+#'
+#'
 #' @param summaryoutput list created by \code{SSsummarize}
 #' @param models optional subset of the models described in
 #' \code{summaryoutput}.  Either "all" or a vector of numbers indicating
@@ -39,13 +39,11 @@ SStableComparisons <-  function(summaryoutput,
                                 names=c("R0",
                                   "steep",
                                   "NatM",
-                                  "Q_calc",
                                   "L_at_Amax",
                                   "VonBert_K",
-                                  "RecrDev_2008",
                                   "SPB_Virg",
-                                  "Bratio_2012",
-                                  "SPRratio_2011"),
+                                  "Bratio_2015",
+                                  "SPRratio_2014"),
                                 digits=NULL,
                                 modelnames="default",
                                 csv=FALSE,
@@ -54,7 +52,7 @@ SStableComparisons <-  function(summaryoutput,
                                 verbose=TRUE,
                                 mcmc=FALSE){
   if(verbose) cat("running SStableComparisons\n")
-  
+
   # get stuff from summary output
   n           <- summaryoutput$n
   nsexes      <- summaryoutput$nsexes
@@ -63,14 +61,14 @@ SStableComparisons <-  function(summaryoutput,
   likelihoods <- summaryoutput$likelihoods
   npars       <- summaryoutput$npars
   indices     <- summaryoutput$indices
-  
+
   if(models[1]=="all") models <- 1:n
   ncols <- length(models)
   nsexes <- nsexes[models]
 
   if(modelnames[1]=="default") modelnames <- paste("model",1:ncols,sep="")
   tab <- as.data.frame(matrix(NA,nrow=0,ncol=ncols+1))
-  
+
   if(!mcmc) {
     if(!is.null(likenames)){
       likenames <- paste(likenames,"_like",sep="")
@@ -92,7 +90,7 @@ SStableComparisons <-  function(summaryoutput,
         # add to table
         tab <- rbind(tab, " ")
       }else{
-        # get values 
+        # get values
         vals <- bigtable[grep(name, bigtable$Label),]
         #      cat("labels found:\n",bigtable$Label[grep(name, bigtable$Label)],"\n")
         # fix scale on a few things
@@ -100,7 +98,7 @@ SStableComparisons <-  function(summaryoutput,
           vals[-1] <- round(exp(vals[-1])/1e6,6)
           vals[1] <- "R0_billions"
         }
-        if(substring(name,1,4)=="Recr") {
+        if(substring(name,1,4)=="Recr" & length(grep("like",name))==0) {
           vals[1,-1] <- round(vals[1,-1]/1e6,6)
           vals[1,1] <-paste(vals[1,1],"billions",sep="_")
         }
@@ -118,7 +116,7 @@ SStableComparisons <-  function(summaryoutput,
         }
 
         if(name %in% c("Q","Q_calc")){
-          Calc_Q <- aggregate(Calc_Q ~ Model+FleetNum,data=indices,FUN=mean)
+          Calc_Q <- aggregate(Calc_Q ~ name+FleetNum,data=indices,FUN=mean)
           cat("\n")
           fleetvec <- sort(as.numeric(unique(Calc_Q$FleetNum)))
           vals <- data.frame(matrix(NA,nrow=length(fleetvec),ncol=ncol(bigtable)))
@@ -140,7 +138,7 @@ SStableComparisons <-  function(summaryoutput,
       } # end if not blank
     } # end loop over names
   } # end if not mcmc
-  
+
   if(mcmc) {
     nnames <- length(names)
     for(iname in 1:nnames){
@@ -152,12 +150,12 @@ SStableComparisons <-  function(summaryoutput,
         # add to table
         tab <- rbind(tab, " ")
       }else{
-        
+
         vals <- as.data.frame(matrix(NA,ncol=ncols+1,nrow=1))
         vals[1] <- name
         for(imodel in models) {   ###loop over models and create a vector of medians to put into tab
           mcmcTable <- summaryoutput$mcmc[[imodel]]
-          # get values 
+          # get values
           tmp <- mcmcTable[,grep(name, names(mcmcTable))]  #for future functionality grabbing more than one column
           #        cat("labels found: ",names(mcmcTable)[grep(name, names(mcmcTable))],"\n")
           if(!is.null(dim(tmp))){
