@@ -1,9 +1,9 @@
-#' function "stackpoly" by Jim Lemon from "plotrix" package
-#' 
+#' modified from "stackpoly" by Jim Lemon from "plotrix" package
+#'
 #' Plot one or more columns of numeric values as the top edges of polygons
 #' instead of lines.
-#' 
-#' 
+#'
+#'
 #' @param x A numeric data frame or matrix with the 'x' values. If 'y' is NULL,
 #' these will become the 'y' values and the 'x' positions will be the integers
 #' from 1 to dim(x)[1].
@@ -19,17 +19,19 @@
 #' @param border Color for the polygon borders.
 #' @param col Color to fill the polygons. If NULL, 'rainbow' will be called to
 #' generate the colors. If NA, the polygons will not be filled.
-#' @param axis4 option to add an axis on the right hand side
+#' @param axis4 option to add an axis on the right hand side.
+#' @param x.hash values from x for which the bars have hash marks instead of solid fill
+#' @param density density value for hashed areas
 #' @param \dots Additional arguments passed to 'plot'.
-#' @author Jim Lemon
+#' @author Jim Lemon, Ian Taylor
 #' @export
-#' @references \url{http://cran.r-project.org/web/packages/plotrix/index.html}
+#' @references \url{https://cran.r-project.org/package=plotrix}
 #' @keywords hplot
 stackpoly <- function (x, y, main="", xlab="", ylab="", xat=NA,
                        xaxlab=NA, xlim=NA, ylim=NA, lty=1, border=NA,
-                       col=NA, axis4=F, ...)
+                       col=NA, axis4=F, x.hash=NULL, density=20, ...)
 ## modified version of function "stackpoly" by Jim Lemon from "plotrix"
-## see http://cran.r-project.org/web/packages/plotrix/index.html
+## see https://cran.r-project.org/package=plotrix
 {
     ydim <- dim(y)
     x <- matrix(rep(x, ydim[2]), ncol = ydim[2])
@@ -47,14 +49,32 @@ stackpoly <- function (x, y, main="", xlab="", ylab="", xat=NA,
         lty <- rep(lty, length.out = ydim[2])
     for (pline in seq(ydim[2], 1, by = -1)) {
         if (pline == 1) {
+          if(x[1]%in%x.hash){
+            polygon(c(x[1], x[, pline], x[ydim[1]]),
+                    c(plotlim[3], y[, pline], plotlim[3]),
+                    border = border, col = col[pline],
+                    lty = lty[pline],
+                    density=density)
+          }else{
             polygon(c(x[1], x[, pline], x[ydim[1]]),
                     c(plotlim[3], y[, pline], plotlim[3]),
                     border = border, col = col[pline],
                     lty = lty[pline])
+          }
+
+        } else {
+          if(x[1,pline]%in%x.hash){
+            polygon(c(x[, pline], rev(x[, pline - 1])),
+                    c(y[, pline], rev(y[, pline - 1])), border = border,
+                    col = col[pline], lty = lty[pline],
+                    density=density)
+          }else{
+            polygon(c(x[, pline], rev(x[, pline - 1])),
+                    c(y[, pline], rev(y[, pline - 1])), border = border,
+                    col = col[pline], lty = lty[pline])
+          }
+
         }
-        else polygon(c(x[, pline], rev(x[, pline - 1])),
-                     c(y[, pline], rev(y[, pline - 1])), border = border,
-                     col = col[pline], lty = lty[pline])
     }
     if (axis4)  axis(4)
 }
